==> ejc-xmgs-impl-3.0.0-20220629.014409-2-sources.jar: com/ejianc/business/xmgs/vo/ProjectVO.java <==
package com.ejianc.business.xmgs.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工时项目
 *
 * @author generator
 *
 */
public class ProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String createUserName; // 创建人名称
    private String billCode; // 单据编码
    private String name; // 项目名称
    private Long customerId; // 客户主键
    private String customerName; // 客户名称
    private Long directorId; // 项目负责人主键
    private String directorName; // 项目负责人名称
    private BigDecimal calculateTime; // 预估工时
    private Integer enabled; // 1：启用 / 0：停用
    private Integer orders; // 顺序
    private String memo; // 备注


    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getDirectorId() {
        return directorId;
    }

    public void setDirectorId(Long directorId) {
        this.directorId = directorId;
    }
    public String getDirectorName() {
        return directorName;
    }

    public void setDirectorName(String directorName) {
        this.directorName = directorName;
    }
    public BigDecimal getCalculateTime() {
        return calculateTime;
    }

    public void setCalculateTime(BigDecimal calculateTime) {
        this.calculateTime = calculateTime;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public Integer getOrders() {
        return orders;
    }

    public void setOrders(Integer orders) {
        this.orders = orders;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-xmgs-impl-3.0.0-20240218.072754-22-sources.jar: com/ejianc/business/xmgs/vo/ProjectVO.java <==
package com.ejianc.business.xmgs.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工时项目
 *
 * @author generator
 *
 */
public class ProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private String name; // 项目名称
    private Long customerId; // 客户主键
    private String customerName; // 客户名称
    private Long directorId; // 项目负责人主键
    private String directorName; // 项目负责人名称
    private BigDecimal calculateTime; // 预估工时
    private Integer enabled; // 1：启用 / 0：停用
    private Integer orders; // 顺序
    private String memo; // 备注
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private String orgCode; // 组织编码

    private List<Long> ids;


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getDirectorId() {
        return directorId;
    }

    public void setDirectorId(Long directorId) {
        this.directorId = directorId;
    }
    public String getDirectorName() {
        return directorName;
    }

    public void setDirectorName(String directorName) {
        this.directorName = directorName;
    }
    public BigDecimal getCalculateTime() {
        return calculateTime;
    }

    public void setCalculateTime(BigDecimal calculateTime) {
        this.calculateTime = calculateTime;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public Integer getOrders() {
        return orders;
    }

    public void setOrders(Integer orders) {
        this.orders = orders;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
}
